@@ -7,7 +7,7 @@ from os import path
 from sunday.core.globalvar import getvar, setvar
 from sunday.core.getConfig import getConfig
 import sunday.core.paths as paths
-from sunday.core.globalKeyMaps import sdvar_loggerid
+from sunday.core.globalKeyMaps import sdvar_loggerid, sdvar_logger
 
 if not getvar(sdvar_loggerid):
     loggerId = datetime.datetime.today().isoformat()
@@ -15,7 +15,7 @@ if not getvar(sdvar_loggerid):
     if getConfig('LOGGING')('print_file'):
         @atexit.register
         def exitPrintLogfile():
-            print('\n    LOG FILE AT: %s' % path.join(paths.logCwd, loggerId))
+            getvar(sdvar_logger).info('LOG FILE AT: %s' % path.join(paths.logCwd, loggerId))
 
 logfile = path.join(paths.logCwd, getvar(sdvar_loggerid))
 
